@@ -4,8 +4,7 @@
   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef MESSAGECOMPOSER_COMPOSER_H
-#define MESSAGECOMPOSER_COMPOSER_H
+#pragma once
 
 #include "MessageComposer/JobBase"
 #include <Libkleo/Enum>
@@ -14,14 +13,15 @@
 #include <QStringList>
 #include <QVector>
 
-#include <kmime/kmime_message.h>
+#include <KMime/KMimeMessage>
 
 #include <MessageCore/AttachmentPart>
 
-#include <vector>
 #include <gpgme++/key.h>
+#include <vector>
 
-namespace MessageComposer {
+namespace MessageComposer
+{
 class ComposerPrivate;
 class GlobalPart;
 class InfoPart;
@@ -52,8 +52,14 @@ public:
     void setNoCrypto(bool noCrypto);
     void setSignAndEncrypt(const bool doSign, const bool doEncrypt);
     void setMessageCryptoFormat(Kleo::CryptoMessageFormat format);
-    void setSigningKeys(std::vector<GpgME::Key> &signers);
-    void setEncryptionKeys(const QVector<QPair<QStringList, std::vector<GpgME::Key> > > &data);
+    void setSigningKeys(const std::vector<GpgME::Key> &signers);
+    void setEncryptionKeys(const QVector<QPair<QStringList, std::vector<GpgME::Key>>> &data);
+
+    void setAutocryptEnabled(bool autocryptEnabled);
+    void setSenderEncryptionKey(const GpgME::Key &senderKey);
+
+    void setGnupgHome(const QString &path);
+    Q_REQUIRED_RESULT QString gnupgHome() const;
 
     /// Sets if this message being composed is an auto-saved message
     ///  if so, might need different handling, such as no crypto attachments.
@@ -76,5 +82,3 @@ private:
     Q_PRIVATE_SLOT(d_func(), void attachmentsFinished(KJob *))
 };
 }
-
-#endif
