@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -11,9 +11,7 @@ using namespace MessageComposer;
 class MessageComposer::PluginEditorCheckBeforeSendParamsPrivate
 {
 public:
-    PluginEditorCheckBeforeSendParamsPrivate()
-    {
-    }
+    PluginEditorCheckBeforeSendParamsPrivate() = default;
 
     QString ccAddresses;
     QString bccAddresses;
@@ -38,10 +36,7 @@ PluginEditorCheckBeforeSendParams::PluginEditorCheckBeforeSendParams(const Plugi
     (*this) = other;
 }
 
-PluginEditorCheckBeforeSendParams::~PluginEditorCheckBeforeSendParams()
-{
-    delete d;
-}
+PluginEditorCheckBeforeSendParams::~PluginEditorCheckBeforeSendParams() = default;
 
 PluginEditorCheckBeforeSendParams &PluginEditorCheckBeforeSendParams::operator=(const PluginEditorCheckBeforeSendParams &other)
 {
