@@ -8,10 +8,10 @@
 
 #include "distributionlistdialog.h"
 
-#include <Akonadi/Contact/ContactGroupSearchJob>
-#include <Akonadi/Contact/ContactSearchJob>
-#include <AkonadiCore/itemcreatejob.h>
-#include <AkonadiWidgets/collectiondialog.h>
+#include <Akonadi/CollectionDialog>
+#include <Akonadi/ContactGroupSearchJob>
+#include <Akonadi/ContactSearchJob>
+#include <Akonadi/ItemCreateJob>
 #include <KEmailAddress>
 
 #include "messagecomposer_debug.h"
@@ -112,16 +112,17 @@ DistributionListDialog::DistributionListDialog(QWidget *parent)
 
     mainLayout->addWidget(buttonBox);
 
-    QBoxLayout *topLayout = new QVBoxLayout(topFrame);
+    auto topLayout = new QVBoxLayout(topFrame);
     topLayout->setContentsMargins({});
 
-    QBoxLayout *titleLayout = new QHBoxLayout;
+    auto titleLayout = new QHBoxLayout;
     topLayout->addLayout(titleLayout);
 
     auto label = new QLabel(i18nc("@label:textbox Name of the distribution list.", "&Name:"), topFrame);
     titleLayout->addWidget(label);
 
     mTitleEdit = new QLineEdit(topFrame);
+    mTitleEdit->setPlaceholderText(i18n("Name of Distribution List"));
     titleLayout->addWidget(mTitleEdit);
     mTitleEdit->setFocus();
     mTitleEdit->setClearButtonEnabled(true);
@@ -187,7 +188,7 @@ void DistributionListDialog::slotDelayedSetRecipients(KJob *job)
     if (akItems.isEmpty()) {
         KContacts::Addressee contact;
         contact.setNameFromString(name);
-        contact.insertEmail(email);
+        contact.addEmail(KContacts::Email(email));
 
         auto item = new DistributionListItem(mRecipientsList);
         item->setAddressee(contact, email);
@@ -330,10 +331,15 @@ void DistributionListDialog::slotTitleChanged(const QString &text)
     mUser1Button->setEnabled(!text.trimmed().isEmpty());
 }
 
+namespace
+{
+static const char myDistributionListDialogGroupName[] = "DistributionListDialog";
+}
+
 void DistributionListDialog::readConfig()
 {
-    KSharedConfig::Ptr cfg = KSharedConfig::openConfig();
-    KConfigGroup group(cfg, "DistributionListDialog");
+    KSharedConfig::Ptr cfg = KSharedConfig::openStateConfig();
+    KConfigGroup group(cfg, myDistributionListDialogGroupName);
     const QSize size = group.readEntry("Size", QSize());
     if (!size.isEmpty()) {
         resize(size);
@@ -343,8 +349,8 @@ void DistributionListDialog::readConfig()
 
 void DistributionListDialog::writeConfig()
 {
-    KSharedConfig::Ptr cfg = KSharedConfig::openConfig();
-    KConfigGroup group(cfg, "DistributionListDialog");
+    KSharedConfig::Ptr cfg = KSharedConfig::openStateConfig();
+    KConfigGroup group(cfg, myDistributionListDialogGroupName);
     group.writeEntry("Size", size());
     group.writeEntry("Header", mRecipientsList->header()->saveState());
 }
