@@ -1,11 +1,10 @@
 /*
-   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef MESSAGECOMPOSER_SENDLATERUTIL_H
-#define MESSAGECOMPOSER_SENDLATERUTIL_H
+#pragma once
 
 #include "messagecomposer_export.h"
 
@@ -21,4 +20,3 @@ Q_REQUIRED_RESULT MESSAGECOMPOSER_EXPORT bool sentLaterAgentWasRegistered();
 Q_REQUIRED_RESULT MESSAGECOMPOSER_EXPORT bool sentLaterAgentEnabled();
 }
 }
-#endif // SENDLATERUTIL_H
