@@ -1,11 +1,10 @@
 /*
-   SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2015-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef DEFAULTGRANTLEEHEADERSTYLEPLUGIN_H
-#define DEFAULTGRANTLEEHEADERSTYLEPLUGIN_H
+#pragma once
 
 #include "messageviewer/headerstyleplugin.h"
 
@@ -28,8 +27,7 @@ public:
 
 private:
     void initializePlugin();
-    GrantleeHeaderStyle *mHeaderStyle = nullptr;
-    HeaderStrategy *mHeaderStrategy = nullptr;
+    GrantleeHeaderStyle *const mHeaderStyle;
+    HeaderStrategy *const mHeaderStrategy;
 };
 }
-#endif // DEFAULTGRANTLEEHEADERSTYLEPLUGIN_H
