@@ -45,7 +45,9 @@ KMime::Message::Ptr TestMailDndAttachment::readAndParseMail(const QString &mailF
 int main(int argc, char *argv[])
 {
     QApplication app(argc, argv);
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     app.setAttribute(Qt::AA_UseHighDpiPixmaps, true);
+#endif
     auto testWebEngine = new TestMailDndAttachment;
     testWebEngine->show();
     const int ret = app.exec();
