@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -42,9 +42,7 @@ CheckPhishingUrlGui::CheckPhishingUrlGui(QWidget *parent)
     layout->addWidget(mJson);
 }
 
-CheckPhishingUrlGui::~CheckPhishingUrlGui()
-{
-}
+CheckPhishingUrlGui::~CheckPhishingUrlGui() = default;
 
 void CheckPhishingUrlGui::slotCheckUrl()
 {
