@@ -1,11 +1,10 @@
 /*
-   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef UPDATEDATABASEINFO_H
-#define UPDATEDATABASEINFO_H
+#pragma once
 
 #include "webengineviewer_export.h"
 #include <QList>
@@ -17,11 +16,19 @@ struct Addition;
 struct Removal;
 struct WEBENGINEVIEWER_EXPORT UpdateDataBaseInfo {
     UpdateDataBaseInfo();
-    bool isValid() const;
+    Q_REQUIRED_RESULT bool isValid() const;
 
-    enum ResponseType { Unknown = 0, FullUpdate = 1, PartialUpdate = 2 };
+    enum ResponseType {
+        Unknown = 0,
+        FullUpdate = 1,
+        PartialUpdate = 2,
+    };
 
-    enum CompressionType { UnknownCompression = 0, RiceCompression = 1, RawCompression = 2 };
+    enum CompressionType {
+        UnknownCompression = 0,
+        RiceCompression = 1,
+        RawCompression = 2,
+    };
 
     QVector<Addition> additionList;
     QVector<Removal> removalList;
@@ -72,5 +79,3 @@ Q_DECLARE_METATYPE(WebEngineViewer::UpdateDataBaseInfo::CompressionType)
 Q_DECLARE_TYPEINFO(WebEngineViewer::Addition, Q_MOVABLE_TYPE);
 Q_DECLARE_TYPEINFO(WebEngineViewer::Removal, Q_MOVABLE_TYPE);
 Q_DECLARE_TYPEINFO(WebEngineViewer::RiceDeltaEncoding, Q_MOVABLE_TYPE);
-
-#endif // UPDATEDATABASEINFO_H
